#!/bin/bash

#configuration part

#file, which first line may contain JVM (made by instalator)
conf_file=path.conf

#please modify this parameter, to modify parameters, sent to java
#java_parameters=' -Xmn128M -Xmx512M -XX:MaxHeapFreeRatio=70 -XX:MinHeapFreeRatio=50 -jar sMpc.jar &'
java_parameters=' -Xmn128M -Xmx512M -XX:MaxHeapFreeRatio=70 -XX:MinHeapFreeRatio=50 -Dsun.java2d.noddraw=true -classpath ./splugin.jar:./sdeploy.jar:./sFoxtrot.jar:./jaws.jar:./sMpc.jar com.raritan.rrc.ui.RRCApplication &'

# end of configuration part

dir=`dirname "$0"`
cd "$dir"

java_start=''

#starts MPC
function startApplication()
{
	eval "$java_start $java_parameters"
}

function echoInvalidPath(){
	echo "Invalid java path: $java_start"
	return 1
}

function figureOutJVM(){
	if [ -n "$java_start" ] && [ -e "$java_start" ]; then
		#echo "Trying with '$java_start' ..."

		if [ -f "$java_start" ] && [ -x "$java_start" ]; then
  			#startApplication
			return 0
		elif [ -f "$java_start/java" ] && [ -x "$java_start/java" ]; then
			java_start=$java_start/java
			#startApplication
			return 0
		elif [ -f "$java_start/bin/java" ] && [ -x "$java_start/bin/java" ]; then
			java_start=$java_start/bin/java
			#startApplication
			return 0
		elif [ -f "$java_start/jre/bin/java" ] && [ -x "$java_start/jre/bin/java" ]; then
			java_start=$java_start/jre/bin/java
			#startApplication
			return 0
		else
			echo "JVM could not be located under $java_start"
			return 1
		fi

	else
		echo "Invalid path: $java_start"
		return 1
	fi
}

#reads first line of the file and if it is real java path, starts java app
function getFirstLine()
{
	local line1
	if [ -f "$conf_file" ]; then
		{
		read line1
		} < $conf_file
	else
		echo "$conf_file not found"
		return 1
	fi

	if [ -n "$line1" ]; then
		java_start="$line1"
	else
		echo "$conf_file is empty"
		return 1
	fi
}

function loadJavaHomeEnv()
{
	local javaEnv=$(echo $JAVA_HOME)

	if [ -n "$javaEnv" ]; then
		java_start="$javaEnv"
		return 0
	else
		echo "JAVA_HOME has not been found"
		return 1
	fi
}

function loadJavaCommand()
{
	jaaa=`which java 2>&1 | grep -c ' no '`
	if [ "$jaaa" -eq "0" ]; then
		java_start=`which java`
		return 0
	else
		echo "java NOT found!"
		return 1
	fi

}

echo

#Try to start MPC via path, in $conf_file
#echo "Trying to start MPC via $conf_file file"
getFirstLine
if [ $? -eq 0 ]; then
	figureOutJVM
	if [ $? -eq 0 ]; then
		startApplication
		exit
	fi
fi
echo

#Try to start MPC Manager via JAVA_HOME
#echo "Trying to start MPC via JAVA_HOME enviroment"
loadJavaHomeEnv
if [ $? -eq 0 ]; then
	figureOutJVM
	if [ $? -eq 0 ]; then
		startApplication
		exit
	fi
fi
echo

#Try to start MPC Manager via java command
#echo "Trying to start MPC via 'java' command"
loadJavaCommand
if [ $? -eq 0 ]; then
	figureOutJVM
	if [ $? -eq 0 ]; then
		startApplication
		exit
	fi
fi
echo

echo "MPC could not be started!"
echo
exit 1



